@@ -35,7 +35,7 @@ License:
 ::
 
 
-    Copyright 2017, 2018, 2019, 2020, 2021 Nissar Chababy
+    Copyright 2017, 2018, 2019, 2020, 2022 Nissar Chababy
 
     Licensed under the Apache License, Version 2.0 (the "License");
     you may not use this file except in compliance with the License.
@@ -183,5 +183,5 @@ class DomainAvailabilityChecker(AvailabilityCheckerBase):
         return self
 
     @staticmethod
-    def is_valid() -> bool:
+    def is_valid() -> bool:  # pylint: disable=arguments-differ
         raise NotImplementedError()
