@@ -35,7 +35,7 @@ License:
 ::
 
 
-    Copyright 2017, 2018, 2019, 2020, 2021 Nissar Chababy
+    Copyright 2017, 2018, 2019, 2020, 2022 Nissar Chababy
 
     Licensed under the Apache License, Version 2.0 (the "License");
     you may not use this file except in compliance with the License.
@@ -398,10 +398,13 @@ class ConfigLoader:
         PyFunceble.storage.HTTP_CODES = Box(
             config["http_codes"],
         )
-        if "collection" in config:
+        if "collection" in config and config["collection"]:
             PyFunceble.storage.COLLECTION = Box(config["collection"])
         PyFunceble.storage.LINKS = Box(config["links"])
 
+        if "proxy" in config and config["proxy"]:
+            PyFunceble.storage.PROXY = Box(config["proxy"])
+
         return self
 
     def destroy(self) -> "ConfigLoader":
@@ -417,6 +420,7 @@ class ConfigLoader:
             PyFunceble.storage.HTTP_CODES = Box({})
             PyFunceble.storage.COLLECTION = Box({})
             PyFunceble.storage.LINKS = Box({})
+            PyFunceble.storage.PROXY = Box({})
         except (AttributeError, TypeError):  # pragma: no cover ## Safety.
             pass
 
