@@ -35,7 +35,7 @@ License:
 ::
 
 
-    Copyright 2017, 2018, 2019, 2020, 2021 Nissar Chababy
+    Copyright 2017, 2018, 2019, 2020, 2022 Nissar Chababy
 
     Licensed under the Apache License, Version 2.0 (the "License");
     you may not use this file except in compliance with the License.
@@ -104,9 +104,6 @@ class HTTPStatusCode:
 
         self._url2netloc = Url2Netloc()
 
-        # Be sure that all settings are loaded proprely!!
-        PyFunceble.factory.Requester.guess_all_settings()
-
     def ensure_subject_is_given(func):  # pylint: disable=no-self-argument
         """
         Ensures that the subject is given before running the decorated method.
