@@ -35,7 +35,7 @@ License:
 ::
 
 
-    Copyright 2017, 2018, 2019, 2020, 2021 Nissar Chababy
+    Copyright 2017, 2018, 2019, 2020, 2022 Nissar Chababy
 
     Licensed under the Apache License, Version 2.0 (the "License");
     you may not use this file except in compliance with the License.
@@ -69,6 +69,7 @@ class RequestAdapterBase(requests.adapters.HTTPAdapter):
     resolving_cache: dict = {}
     resolving_use_cache: bool = False
     timeout: float = 5.0
+    proxy_pattern: dict = {}
 
     def __init__(self, *args, **kwargs):
         if "timeout" in kwargs:
@@ -86,6 +87,12 @@ class RequestAdapterBase(requests.adapters.HTTPAdapter):
         else:
             self.dns_query_tool = DNSQueryTool()
 
+        if "proxy_pattern" in kwargs:
+            self.proxy_pattern = kwargs["proxy_pattern"]
+            del kwargs["proxy_pattern"]
+        else:
+            self.proxy_pattern = {}
+
         super().__init__(*args, **kwargs)
 
     @staticmethod
@@ -99,6 +106,108 @@ class RequestAdapterBase(requests.adapters.HTTPAdapter):
             "Could not resolve."
         )
 
+    @staticmethod
+    def extract_extension(subject: str) -> Optional[str]:
+        """
+        Provides the extension of the given subject.
+
+        .. versionchanged:: 4.1.1.dev
+            Handle the case that the given subject does not have a `.` (point).
+
+        :param str subject:
+            The subject to get extract the extension from.
+
+        :raise TypeError:
+            When the given :code:`subject` is not a :py:class:`str`.
+        :raise ValueError:
+            When the given :code:`subject` is an empty :py:class:`str`.
+        """
+
+        if not isinstance(subject, str):
+            raise TypeError(f"<subject> should be {str}, type(subject) given.")
+
+        if not subject:
+            raise ValueError("<subject> should not be empty.")
+
+        if "." not in subject:
+            return None
+
+        if subject.endswith("."):
+            # Absolute needs a little correction.
+            last_point = subject[:-1].rfind(".")
+        else:
+            last_point = subject.rindex(".")
+
+        extension = subject[last_point + 1 :]
+
+        if extension.endswith("."):
+            return extension[:-1]
+        return extension
+
+    def fetch_proxy_from_pattern(self, subject: str) -> dict:
+        """
+        Provides the proxy settings to use for the given subject.
+
+        .. versionchanged:: 4.1.1.dev
+            Handle the case that the given subject has no extension/TLD.
+
+        :param str subject:
+            The subject to work with.
+
+        :raise TypeError:
+            When the given :code:`subject` is not a :py:class:`str`.
+        :raise ValueError:
+            When the given :code:`subject` is an empty :py:class:`str`.
+        """
+
+        def correct_input(pattern_input: dict) -> dict:
+            result = {}
+
+            if "http" in pattern_input and pattern_input["http"]:
+                result["http"] = pattern_input["http"]
+
+            if "https" in pattern_input and pattern_input["https"]:
+                result["https"] = pattern_input["https"]
+
+            if "http" in result and "https" not in result:
+                result["https"] = result["http"]
+
+            if "https" in result and "http" not in result:
+                result["http"] = result["https"]
+
+            return result
+
+        if not isinstance(subject, str):
+            raise TypeError(f"<subject> should be {str}, type(subject) given.")
+
+        if not subject:
+            raise ValueError("<subject> should not be empty.")
+
+        extension = self.extract_extension(subject)
+
+        proxies = {}
+
+        if extension and "rules" in self.proxy_pattern:
+            for rule in self.proxy_pattern["rules"]:
+                local_proxy = {}
+
+                if "http" in rule and rule["http"]:
+                    local_proxy["http"] = rule["http"]
+                if "https" in rule and rule["https"]:
+                    local_proxy["https"] = rule["https"]
+
+                if not local_proxy:
+                    continue
+
+                if "tld" in rule and extension in rule["tld"]:
+                    proxies = correct_input(local_proxy)
+                    break
+
+        if not proxies and "global" in self.proxy_pattern:
+            proxies = correct_input(self.proxy_pattern["global"])
+
+        return proxies
+
     def resolve_with_cache(self, hostname: str) -> Optional[str]:
         """
         Try to resolve using an internal cache.
@@ -117,7 +226,7 @@ class RequestAdapterBase(requests.adapters.HTTPAdapter):
             The hostname to get resolve.
         """
 
-        def get_last_cname(subject: str) -> Optional[str]:
+        def get_last_cname(subject: str, recursion_depth: int = 60) -> Optional[str]:
             """
             Given a subject, this function tries to query the CNAME until there
             is none.
@@ -129,13 +238,17 @@ class RequestAdapterBase(requests.adapters.HTTPAdapter):
             last_cname_result = []
             last_cname_new_subject = subject
 
-            while True:
+            depth = 0
+
+            while depth < recursion_depth:
                 local_last_cname_result = (
                     self.dns_query_tool.set_query_record_type("CNAME")
                     .set_subject(last_cname_new_subject)
                     .query()
                 )
 
+                depth += 1
+
                 if any(x in last_cname_result for x in local_last_cname_result):
                     break
 
