@@ -35,7 +35,7 @@ License:
 ::
 
 
-    Copyright 2017, 2018, 2019, 2020, 2021 Nissar Chababy
+    Copyright 2017, 2018, 2019, 2020, 2022 Nissar Chababy
 
     Licensed under the Apache License, Version 2.0 (the "License");
     you may not use this file except in compliance with the License.
@@ -78,10 +78,49 @@ class Requester:
         Optional, The timeout to apply to the query.
     :param int max_redirects:
         Optional, The maximum number of redirects to allow.
+    :param dns_query_tool:
+        Optional, The DNS Query tool to use.
+    :param proxy_pattern:
+        Optional, The proxy pattern to apply to each query.
+
+        Expected format:
+
+            ::
+                {
+                    "global": {
+                        # Everything under global will be used as default if no
+                        # rule matched.
+
+                        "http": "str" ## HTTP_PROXY
+                        "https": "str" ## HTTPS_PROXY
+                    },
+                    "rules":[
+                        # A set/list of rules to work with.
+
+                        {
+                            "http": "str" ## HTTP_PROXY when TLD is matched.
+                            "https": "str" ## HTTPS_PROXY when TLD is matched.
+                            "tld": [
+                                "str",
+                                "str",
+                                str
+                            ]
+                        },
+                        {
+                            "http": "str" ## HTTP_PROXY when TLD is matched.
+                            "https": "str" ## HTTPS_PROXY when TLD is matched.
+                            "tld": [
+                                "str",
+                                "str"
+                            ]
+                        },
+                    ]
+                }
     """
 
     STD_VERIFY_CERTIFICATE: bool = False
     STD_TIMEOUT: float = 3.0
+    STD_MAX_RETRIES: int = 3
 
     urllib3_exceptions = urllib3.exceptions
     exceptions = requests.exceptions
@@ -90,6 +129,7 @@ class Requester:
     _max_retries: int = 3
     _verify_certificate: bool = True
     _max_redirects: int = 60
+    _proxy_pattern: dict = {}
 
     session: Optional[requests.Session] = None
     dns_query_tool: Optional[DNSQueryTool] = None
@@ -102,9 +142,12 @@ class Requester:
         timeout: Optional[float] = None,
         max_redirects: Optional[int] = None,
         dns_query_tool: Optional[DNSQueryTool] = None,
+        proxy_pattern: Optional[dict] = None,
     ) -> None:
         if max_retries is not None:
             self.max_retries = max_retries
+        else:
+            self.guess_and_set_max_retries()
 
         if verify_certificate is not None:
             self.verify_certificate = verify_certificate
@@ -124,6 +167,11 @@ class Requester:
         else:
             self.dns_query_tool = DNSQueryTool()
 
+        if proxy_pattern is not None:
+            self.proxy_pattern = proxy_pattern
+        else:
+            self.guess_and_set_proxy_pattern()
+
         self.session = self.get_session()
 
         warnings.simplefilter("ignore", urllib3.exceptions.InsecureRequestWarning)
@@ -203,8 +251,8 @@ class Requester:
         if not isinstance(value, int):
             raise TypeError(f"<value> should be {int}, {type(value)} given.")
 
-        if value < 1:
-            raise ValueError(f"<value> ({value!r}) should not be less than 1.")
+        if value < 0:
+            raise ValueError(f"<value> ({value!r}) should be positive.")
 
         self._max_retries = value
 
@@ -220,6 +268,22 @@ class Requester:
 
         return self
 
+    def guess_and_set_max_retries(self) -> "Requester":
+        """
+        Try to guess the value from the configuration and set it.
+        """
+
+        if PyFunceble.facility.ConfigLoader.is_already_loaded() and bool(
+            PyFunceble.storage.CONFIGURATION.max_http_retries
+        ):
+            self.set_max_retries(
+                bool(PyFunceble.storage.CONFIGURATION.max_http_retries)
+            )
+        else:
+            self.set_max_retries(self.STD_MAX_RETRIES)
+
+        return self
+
     @property
     def max_redirects(self) -> int:
         """
@@ -375,6 +439,58 @@ class Requester:
 
         return self
 
+    @property
+    def proxy_pattern(self) -> Optional[dict]:
+        """
+        Provides the current state of the :code:`_proxy_pattern` attribute.
+        """
+
+        return self._proxy_pattern
+
+    @proxy_pattern.setter
+    @recreate_session
+    def proxy_pattern(self, value: dict) -> None:
+        """
+        Overwrite the proxy pattern to use.
+
+        :param value:
+            The value to set.
+
+        :raise TypeError:
+            When the given :code:`value` is not a :py:class`dict`.
+        """
+
+        if not isinstance(value, dict):
+            raise TypeError(f"<value> shoule be {dict}, {type(value)} given.")
+
+        self._proxy_pattern = value
+
+    def set_proxy_pattern(self, value: dict) -> "Requester":
+        """
+        Overwrite the proxy pattern.
+
+        :param value:
+            The value to set.
+        """
+
+        self.proxy_pattern = value
+
+        return self
+
+    def guess_and_set_proxy_pattern(self) -> "Requester":
+        """
+        Try to guess the value from the configuration and set it.
+        """
+
+        if PyFunceble.facility.ConfigLoader.is_already_loaded() and bool(
+            PyFunceble.storage.CONFIGURATION.proxy
+        ):
+            self.set_proxy_pattern(PyFunceble.storage.CONFIGURATION.proxy)
+        else:
+            self.set_proxy_pattern({})
+
+        return self
+
     def guess_all_settings(self) -> "Requester":
         """
         Try to guess all settings.
@@ -413,13 +529,13 @@ class Requester:
 
         session.verify = self.verify_certificate
         session.max_redirects = self.max_redirects
-
         session.mount(
             "https://",
             RequestHTTPSAdapter(
                 max_retries=self.max_retries,
                 timeout=self.timeout,
                 dns_query_tool=self.dns_query_tool,
+                proxy_pattern=self.proxy_pattern,
             ),
         )
         session.mount(
@@ -428,6 +544,7 @@ class Requester:
                 max_retries=self.max_retries,
                 timeout=self.timeout,
                 dns_query_tool=self.dns_query_tool,
+                proxy_pattern=self.proxy_pattern,
             ),
         )
 
